@@ -559,8 +559,10 @@ static void checktimeouts() {
 
 	if (!ses.kexstate.sentkexinit
 			&& (elapsed(now, ses.kexstate.lastkextime) >= KEX_REKEY_TIMEOUT
-			|| ses.kexstate.datarecv+ses.kexstate.datatrans >= KEX_REKEY_DATA)) {
+			|| ses.kexstate.datarecv+ses.kexstate.datatrans >= KEX_REKEY_DATA
+			|| ses.kexstate.needrekey)) {
 		TRACE(("rekeying after timeout or max data reached"))
+		ses.kexstate.needrekey = 0;
 		send_msg_kexinit();
 	}
 
@@ -612,6 +614,9 @@ static long select_timeout() {
 	if (!ses.kexstate.sentkexinit) {
 		update_timeout(KEX_REKEY_TIMEOUT, now, ses.kexstate.lastkextime, &timeout);
 	}
+	if (ses.kexstate.needrekey) {
+		timeout = 0;
+	}
 
 	if (ses.authstate.authdone != 1 && IS_DROPBEAR_SERVER) {
 		/* AUTH_TIMEOUT is only relevant before authdone */
