@@ -145,8 +145,6 @@ static void sesssigchild_handler(int UNUSED(dummy)) {
 
 	const int saved_errno = errno;
 
-	TRACE(("enter sigchld handler"))
-
 	/* Make sure that the main select() loop wakes up */
 	while (1) {
 		/* isserver is just a random byte to write. We can't do anything
@@ -161,7 +159,6 @@ static void sesssigchild_handler(int UNUSED(dummy)) {
 	sa_chld.sa_flags = SA_NOCLDSTOP;
 	sigemptyset(&sa_chld.sa_mask);
 	sigaction(SIGCHLD, &sa_chld, NULL);
-	TRACE(("leave sigchld handler"))
 
 	errno = saved_errno;
 }
